@@ -79,13 +79,10 @@ class LaunchTemplate(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name,
+        return {'name': self.name,
                 'http_token': self.http_token,
                 'image_id': self.image_id,
-                'security_group_ids': self.security_group_ids,
-                'version_number': self.version_number,
                 'iam_instance_profile': self.iam_instance_profile,
-                'network_configurations': self.network_configurations and [config.to_dict() for config in self.network_configurations],
                 'ebs_optimized': self.ebs_optimized,
                 'monitoring_enabled': self.monitoring_enabled,
                 'instance_type': self.instance_type}
