@@ -53,5 +53,5 @@ class RouteTableAssociation(AwsResource):
         return self.association_id
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'subnet_id': self.subnet_id,
+        return {'subnet_id': self.subnet_id,
                 'route_table_id': self.route_table_id}
