@@ -5,6 +5,7 @@ from cloudrail.knowledge.context.aws.resources.ec2.route_table import RouteTable
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName, AwsServiceAttributes
 from cloudrail.knowledge.context.aws.resources.iam.policy import Policy
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class VpcEndpointServiceType(Enum):
@@ -54,9 +55,8 @@ class VpcEndpoint(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpc_id': self.vpc_id,
-                'service_name': self.service_name,
-                'state': self.state}
+        return {'tags': filter_tags(self.tags), 'vpc_id': self.vpc_id,
+                'service_name': self.service_name}
 
 
 class VpcEndpointGateway(VpcEndpoint):
@@ -72,10 +72,9 @@ class VpcEndpointGateway(VpcEndpoint):
         return super().get_type(is_plural) + ' Gateway'
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpce_id': self.vpce_id,
+        return {'tags': filter_tags(self.tags), 'vpce_id': self.vpce_id,
                 'vpc_id': self.vpc_id,
                 'service_name': self.service_name,
-                'state': self.state,
                 'route_table_ids': self.route_table_ids}
 
 
@@ -100,10 +99,9 @@ class VpcEndpointInterface(VpcEndpoint, NetworkEntity):
         return super().get_type(is_plural) + ' Interface'
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpce_id': self.vpce_id,
+        return {'tags': filter_tags(self.tags), 'vpce_id': self.vpce_id,
                 'vpc_id': self.vpc_id,
                 'service_name': self.service_name,
-                'state': self.state,
                 'subnet_ids': self.subnet_ids,
                 'security_group_ids': self.security_group_ids,
                 'network_interface_ids': self.network_interface_ids}
