@@ -2,6 +2,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.networking_config.network_configuration import NetworkConfiguration
 from cloudrail.knowledge.context.aws.resources.networking_config.network_entity import NetworkEntity
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class EmrCluster(NetworkEntity):
@@ -63,7 +64,8 @@ class EmrCluster(NetworkEntity):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'cluster_name': self.cluster_name,
+        return {'tags': filter_tags(self.tags),
+                'cluster_name': self.cluster_name,
                 'assign_public_ip': self.vpc_config and self.vpc_config.assign_public_ip,
                 'subnet_list_ids': self.vpc_config and self.vpc_config.subnet_list_ids,
                 'security_groups_ids': self.vpc_config and self.vpc_config.security_groups_ids,
