@@ -1,6 +1,7 @@
 from typing import List
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class GlueCrawler(AwsResource):
@@ -45,5 +46,5 @@ class GlueCrawler(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'crawler_name': self.crawler_name,
+        return {'tags': filter_tags(self.tags), 'crawler_name': self.crawler_name,
                 'database_name': self.database_name}
