@@ -79,4 +79,4 @@ class IamIdentity(AwsResource, ConnectionInstance, Cloneable):
                 self.permissions_policies.append(policy)
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, }
+        return {}
