@@ -3,6 +3,7 @@ from typing import List
 from cloudrail.knowledge.context.aws.resources.ec2.ec2_instance import Ec2Instance
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class IamInstanceProfile(AwsResource):
@@ -28,6 +29,9 @@ class IamInstanceProfile(AwsResource):
 
         return ', '.join([role_name])
 
+    def get_id(self) -> str:
+        return self.iam_instance_profile_name
+
     def get_type(self, is_plural: bool = False) -> str:
         if not is_plural:
             return 'IAM Instance profile'
@@ -46,5 +50,6 @@ class IamInstanceProfile(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'role_name': self.role_name,
+        return {'tags': filter_tags(self.tags),
+                'role_name': self.role_name,
                 'iam_instance_profile_name': self.iam_instance_profile_name}
