@@ -37,5 +37,5 @@ class PolicyRoleAttachment(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'policy_arn': self.policy_arn,
+        return {'policy_arn': self.policy_arn,
                 'role_name': self.role_name}
