@@ -3,6 +3,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.networking_config.network_configuration import NetworkConfiguration
 from cloudrail.knowledge.context.aws.resources.networking_config.network_entity import NetworkEntity
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class KinesisFirehoseStream(NetworkEntity):
@@ -63,7 +64,7 @@ class KinesisFirehoseStream(NetworkEntity):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'stream_name': self.stream_name,
+        return {'tags': filter_tags(self.tags), 'stream_name': self.stream_name,
                 'encrypted_at_rest': self.encrypted_at_rest,
                 'es_domain_arn': self.es_domain_arn,
                 'assign_public_ip': self.es_vpc_config and self.es_vpc_config.assign_public_ip,
