@@ -49,6 +49,6 @@ class S3OutpostEndpoint(NetworkEntity):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'assign_public_ip': self.vpc_config and self.vpc_config.assign_public_ip,
+        return {'assign_public_ip': self.vpc_config and self.vpc_config.assign_public_ip,
                 'security_groups_ids': self.vpc_config and self.vpc_config.security_groups_ids,
                 'subnet_list_ids': self.vpc_config and self.vpc_config.subnet_list_ids}
