@@ -3,6 +3,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.aws_policied_resource import PoliciedResource
 from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class SecretsManagerSecret(PoliciedResource):
@@ -42,5 +43,6 @@ class SecretsManagerSecret(PoliciedResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'sm_name': self.sm_name,
+        return {'tags': filter_tags(self.tags),
+                'sm_name': self.sm_name,
                 'kms_key': self.kms_key}
