@@ -34,5 +34,5 @@ class AzureNetworkInterfaceSecurityGroupAssociation(AzureResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'network_interface_id': self.network_interface_id,
+        return {'network_interface_id': self.network_interface_id,
                 'network_security_group_id': self.network_security_group_id}
