@@ -1,10 +1,14 @@
 from cloudrail.knowledge.context.gcp.gcp_environment_context import GcpEnvironmentContext
 from cloudrail.knowledge.context.environment_context.business_logic.dependency_invocation import DependencyInvocation
+from cloudrail.knowledge.context.gcp.pseudo_builder import PseudoBuilder
 
 
 class GcpRelationsAssigner(DependencyInvocation):
 
     def __init__(self, ctx: GcpEnvironmentContext = None):
+        self.pseudo_builder = PseudoBuilder(ctx)
+        self.pseudo_builder.create_default_firewalls()
+
         function_pool = [
         ]
 
