@@ -146,6 +146,10 @@ class GcpSqlDatabaseInstance(GcpResource):
     def get_keys(self) -> List[str]:
         return [self.name, self.project_id]
 
+    @property
+    def is_labeled(self) -> bool:
+        return True
+
     @property
     def is_tagable(self) -> bool:
         return False
@@ -164,4 +168,5 @@ class GcpSqlDatabaseInstance(GcpResource):
 
     def to_drift_detection_object(self) -> dict:
         return {'name': self.name,
-                'settings': self.settings and dataclasses.asdict(self.settings)}  # TODO: check drift detection on this resource
+                'settings': self.settings and dataclasses.asdict(self.settings),
+                'labels': self.labels}
