@@ -1,11 +1,10 @@
 from typing import Dict, List
-
-from cloudrail.knowledge.context.aws.iam.policy import S3Policy
-from cloudrail.knowledge.context.aws.iam.policy_statement import StatementEffect
-from cloudrail.knowledge.context.aws.s3.s3_bucket import S3Bucket
-from cloudrail.knowledge.context.aws.ec2.vpc import Vpc
-from cloudrail.knowledge.context.aws.ec2.vpc_endpoint import VpcEndpoint
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.resources.resource_based_policy import ResourceBasedPolicy
+from cloudrail.knowledge.context.aws.resources.iam.policy_statement import StatementEffect
+from cloudrail.knowledge.context.aws.resources.s3.s3_bucket import S3Bucket
+from cloudrail.knowledge.context.aws.resources.ec2.vpc import Vpc
+from cloudrail.knowledge.context.aws.resources.ec2.vpc_endpoint import VpcEndpoint
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
@@ -13,7 +12,7 @@ from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterT
 
 class S3BucketPolicyVpcEndpointRule(AwsBaseRule):
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues_list: List[Issue] = []
         vpc_to_buckets_map: Dict[Vpc, List[S3Bucket]] = self._create_vpc_to_buckets_map(env_context)
         for vpc, bucket_list in vpc_to_buckets_map.items():
@@ -33,7 +32,7 @@ class S3BucketPolicyVpcEndpointRule(AwsBaseRule):
         return "s3_bucket_policy_vpce"
 
     @staticmethod
-    def _create_vpc_to_buckets_map(env_context: EnvironmentContext) -> Dict[Vpc, List[S3Bucket]]:
+    def _create_vpc_to_buckets_map(env_context: AwsEnvironmentContext) -> Dict[Vpc, List[S3Bucket]]:
         region_to_buckets_map: Dict[str, List[S3Bucket]] = {}
         vpc_to_buckets_map: Dict[Vpc, List[S3Bucket]] = {}
 
@@ -50,11 +49,11 @@ class S3BucketPolicyVpcEndpointRule(AwsBaseRule):
         return vpc_to_buckets_map
 
     @staticmethod
-    def _is_restrict_to_s3_vpce(policy: S3Policy, s3_vpce: VpcEndpoint) -> bool:
+    def _is_restrict_to_s3_vpce(policy: ResourceBasedPolicy, s3_vpce: VpcEndpoint) -> bool:
         for statement in policy.statements:
-            expected_operator_prefix: str = "String" if statement.effect == StatementEffect.ALLOW else "StringNot"
             for condition_block in statement.condition_block:
-                if condition_block.operator.startswith(expected_operator_prefix) and \
+                if ((statement.effect == StatementEffect.ALLOW and not condition_block.operator.startswith("StringNot") or
+                     statement.effect == StatementEffect.DENY and condition_block.operator.startswith("StringNot"))) and \
                         condition_block.key == "aws:SourceVpce" and \
                         s3_vpce.vpce_id in condition_block.values:
                     return True
@@ -64,5 +63,5 @@ class S3BucketPolicyVpcEndpointRule(AwsBaseRule):
     def _filter_by_service_name(vpc: Vpc, service_name: str = "s3"):
         return [s3_vpce for s3_vpce in vpc.endpoints if s3_vpce.service_name.endswith(f".{service_name}")]
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.s3_buckets)
